@@ -12,7 +12,7 @@ use Carp qw( croak );
 use File::Temp ();
 
 # ABSTRACT: interface to open3 under AnyEvent
-our $VERSION = '0.77'; # VERSION
+our $VERSION = '0.78'; # VERSION
 
 
 sub new
@@ -74,7 +74,7 @@ sub run
   
   my $proc = AnyEvent::Open3::Simple::Process->new($pid, $child_stdin);
   
-  $self->{on_start}->($proc);
+  $self->{on_start}->($proc, $program, @arguments);
 
   my $watcher_stdout;
   my $watcher_stderr;
@@ -225,7 +225,7 @@ AnyEvent::Open3::Simple - interface to open3 under AnyEvent
 
 =head1 VERSION
 
-version 0.77
+version 0.78
 
 =head1 SYNOPSIS
 
@@ -238,6 +238,8 @@ version 0.77
  my $ipc = AnyEvent::Open3::Simple->new(
    on_start => sub {
      my $proc = shift;       # isa AnyEvent::Open3::Simple::Process
+     my $program = shift;    # string
+     my @args = @_;          # list of arguments
      say 'child PID: ', $proc->pid;
    },
    on_stdout => sub { 
@@ -336,11 +338,15 @@ will be called.
 
 =over 4
 
-=item * C<on_start> ($proc)
+=item * C<on_start> ($proc, $program, @arguments)
 
 Called after the process is created, but before the run method returns
 (that is, it does not wait to re-enter the event loop first).
 
+In versions 0.78 and better, this event also gets the program name
+and arguments passed into the L<run|AnyEvent::Open3::Simple#run>
+method.
+
 =item * C<on_error> ($error, $program, @arguments)
 
 Called when there is an execution error, for example, if you ask
